@@ -59,15 +59,14 @@ GType       gs_window_get_type           (void);
 gboolean    gs_window_is_obscured        (GSWindow  *window);
 gboolean    gs_window_is_dialog_up       (GSWindow  *window);
 
-void        gs_window_set_screen         (GSWindow  *window,
-        GdkScreen *screen);
-GdkScreen * gs_window_get_screen         (GSWindow  *window);
-void        gs_window_set_monitor        (GSWindow  *window,
-        int        monitor);
-int         gs_window_get_monitor        (GSWindow  *window);
+GdkDisplay * gs_window_get_display       (GSWindow  *window);
+
+void        gs_window_set_monitor        (GSWindow   *window,
+                                          GdkMonitor *monitor);
+GdkMonitor * gs_window_get_monitor        (GSWindow  *window);
 
 void        gs_window_set_background_surface (GSWindow *window,
-                                              cairo_surface_t *surface);
+        cairo_surface_t *surface);
 void        gs_window_set_lock_enabled   (GSWindow  *window,
         gboolean   lock_enabled);
 void        gs_window_set_logout_enabled (GSWindow  *window,
@@ -92,9 +91,9 @@ void        gs_window_show_message         (GSWindow   *window,
 void        gs_window_request_unlock     (GSWindow  *window);
 void        gs_window_cancel_unlock_request (GSWindow  *window);
 
-GSWindow  * gs_window_new                (GdkScreen *screen,
-        int        monitor,
-        gboolean   lock_enabled);
+GSWindow  * gs_window_new                (GdkDisplay *display,
+                                          GdkMonitor *monitor,
+                                          gboolean   lock_enabled);
 void        gs_window_show               (GSWindow  *window);
 void        gs_window_destroy            (GSWindow  *window);
 GdkWindow * gs_window_get_gdk_window     (GSWindow  *window);
