@@ -387,14 +387,10 @@ help_display (void)
 	GError *error;
 
 	error = NULL;
-#if GTK_CHECK_VERSION (3, 22, 0)
 	gtk_show_uri_on_window (NULL,
                                 "help:mate-user-guide/prefs-screensaver",
                                 GDK_CURRENT_TIME,
                                 &error);
-#else
-	gtk_show_uri (NULL, "help:mate-user-guide/prefs-screensaver", GDK_CURRENT_TIME, &error);
-#endif
 
 	if (error != NULL)
 	{
@@ -942,7 +938,7 @@ time_to_string_text (long time)
 	char *secs, *mins, *hours, *string;
 	int   sec, min, hour;
 
-	int   inc_len, len_minutes;
+	int n, inc_len, len_minutes;
 
 	sec = time % 60;
 	time = time - sec;
@@ -967,7 +963,7 @@ time_to_string_text (long time)
 
 	len_minutes = 0;
 
-	for (int n = 2; n < 60; n++)
+	for (n = 2; n < 60; n++)
 	{
 		if (n < 10)
 		{
@@ -1284,13 +1280,9 @@ constrain_list_size (GtkWidget      *widget,
 {
 	GtkRequisition req;
 	int            max_height;
-	int            sc_height;
 
 	/* constrain height to be the tree height up to a max */
-	gdk_window_get_geometry (gdk_screen_get_root_window (gtk_widget_get_screen (widget)),
-				 NULL, NULL, NULL, &sc_height);
-
-	max_height = sc_height / 4;
+	max_height = (HeightOfScreen (gdk_x11_screen_get_xscreen (gtk_widget_get_screen (widget)))) / 4;
 
 	gtk_widget_get_preferred_size (to_size, &req, NULL);
 	allocation->height = MIN (req.height, max_height);
